==> person_local-0.0.65.tar.gz: person_local-0.0.65/person_local/src/person.py <==
from datetime import datetime

from database_mysql_local.point import Point
from people_local.people import PeopleLocal


# TOOO Person -> PersonLocal
class Person:
    """person details class"""

    # TODO Adding is_same_person() method which override people.is_same_entity() checking username only
    """
  	is_same_person()
		(one of the verified emails is same)
        OR
        (One of the verified telephones is same)  
    """

    # TODO: is there a way to give a default values for Point? Point(None, None) is not working
    # TODO We prefer not to use Point(0,0) and use NULL in the database
    def __init__(self, number: int = None, last_coordinate: Point = Point(0, 0),
                 # TODO birthdat_data_object (unlike birthday_date_str)
                 birthday_date: datetime.date = None, day: int = None,
                 month: int = None, year: int = None, first_name: str = None,
                 last_name: str = None, location_id: int = None,
                 nickname: str = None, gender_id: int = None,
                 father_name: str = None, main_email_address: str = None,
                 birthday_original: str = None, is_approved: bool = False,
                 is_identity_confirmed: bool = False, birthday_timestamp: str = None,
                 year_cira: int = None, first_name_approved: bool = False,
                 last_name_approved: bool = False, nickname_approved: bool = False,
                 last_location_id: int = None, is_rip: bool = False, is_test_data: bool = False) -> None:
        if first_name:
            if len(first_name.split()) > 1 and last_name is None:
                # TODO: We may have to improve it later
                splitted_name_dict = PeopleLocal.split_first_name_field(first_name=first_name)
                first_name = splitted_name_dict.get('first_name')
                last_name = splitted_name_dict.get('last_name')
        self.number = number
        self.gender_id = gender_id
        self.last_coordinate = last_coordinate
        self.location_id = location_id
        self.birthday_date = birthday_date
        self.day = day
        self.month = month
        self.year = year
        self.first_name = first_name
        self.last_name = last_name
        self.nickname = nickname
        self.father_name = father_name
        self.main_email_address = main_email_address
        self.birthday_original = birthday_original
        self.is_approved = is_approved
        self.is_identity_confirmed = is_identity_confirmed
        self.birthday_timestamp = birthday_timestamp
        self.year_cira = year_cira
        self.first_name_approved = first_name_approved
        self.last_name_approved = last_name_approved
        self.nickname_approved = nickname_approved
        self.last_location_id = last_location_id
        self.is_rip = is_rip
        self.is_test_data = is_test_data

==> person_local-0.0.67.tar.gz: person_local-0.0.67/person_local/src/person.py <==
from datetime import datetime

from database_mysql_local.point import Point
from people_local.people import PeopleLocal


# TOOO Person -> PersonLocal
class Person:
    """person details class"""

    # TODO Adding is_same_person() method which override people.is_same_entity() checking username only
    """
  	is_same_person()
		(one of the verified emails is same)
        OR
        (One of the verified telephones is same)  
    """

    # TODO: is there a way to give a default values for Point? Point(None, None) is not working
    # TODO We prefer not to use Point(0,0) and use NULL in the database
    def __init__(self, *, name: str = None, number: int = None, last_coordinate: Point = Point(0, 0),
                 # TODO birthdat_data_object (unlike birthday_date_str)
                 birthday_date: datetime.date = None, day: int = None,
                 month: int = None, year: int = None, first_name: str = None,
                 last_name: str = None, location_id: int = None,
                 nickname: str = None, gender_id: int = None,
                 father_name: str = None, main_email_address: str = None,
                 birthday_original: str = None, is_approved: bool = False,
                 is_identity_confirmed: bool = False, birthday_timestamp: str = None,
                 year_cira: int = None, is_first_name_approved: bool = False,
                 is_last_name_approved: bool = False, is_nickname_approved: bool = False,
                 last_location_id: int = None, is_rip: bool = False, is_test_data: bool = False) -> None:
        if first_name:
            if len(first_name.split()) > 1 and last_name is None:  # TODO: test
                # TODO: We may have to improve it later
                splitted_name_dict = PeopleLocal.split_first_name_field(first_name=first_name)
                first_name = splitted_name_dict.get('first_name')
                last_name = splitted_name_dict.get('last_name')
        self.number = number
        self.gender_id = gender_id
        self.last_coordinate = last_coordinate
        self.location_id = location_id
        self.birthday_date = birthday_date
        self.day = day
        self.month = month
        self.year = year
        self.first_name = first_name
        self.last_name = last_name
        self.nickname = nickname
        self.name = name or (first_name + " " + last_name if first_name and last_name else first_name or last_name)
        self.father_name = father_name
        self.main_email_address = main_email_address
        self.name = self.generate_name()
        self.birthday_original = birthday_original
        self.is_approved = is_approved
        self.is_identity_confirmed = is_identity_confirmed
        self.birthday_timestamp = birthday_timestamp
        self.year_cira = year_cira
        self.is_first_name_approved = is_first_name_approved
        self.is_last_name_approved = is_last_name_approved
        self.is_nickname_approved = is_nickname_approved
        self.last_location_id = last_location_id
        self.is_rip = is_rip
        self.is_test_data = is_test_data

    def generate_name(self) -> str:
        if self.first_name and self.last_name and self.main_email_address:
            return f'{self.first_name} {self.last_name} {self.main_email_address}'
        elif self.first_name and self.last_name:
            return f'{self.first_name} {self.last_name}'
        elif self.first_name and self.main_email_address:
            return f'{self.first_name} {self.main_email_address}'
        elif self.first_name:
            return f'{self.first_name}'
